# Generated by Django 2.0 on 2017-12-19 14:26

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Event',
            fields=[
                ('key', models.CharField(max_length=100, primary_key=True, serialize=False, verbose_name='key')),
                ('group', models.CharField(db_index=True, max_length=50, verbose_name='group')),
                ('created_at', models.DateTimeField(auto_now_add=True, verbose_name='created at')),
            ],
            options={
                'verbose_name': 'events',
                'ordering': ['-created_at'],
            },
        ),
    ]
